<?php
class Product{ 
    
    private $conn;
    private $productTable = "products";      
    public $id;
    public $name;
    public $description;
    public $price;
    public $category_id;
    public $category_name;
    public $created; 
    
    public function __construct($db){
        $this->conn = $db;
    }	
	
	function read(){	
		if($this->id) {
			$stmt = $this->conn->prepare("SELECT * FROM ".$this->productTable." WHERE id = ?");
			$stmt->bind_param("i", $this->id);					
		} else {
			$stmt = $this->conn->prepare("SELECT * FROM ".$this->productTable);		
		}		
		$stmt->execute();			
		$result = $stmt->get_result();		
		return $result;	
	}
	
	function create(){
		
		$stmt = $this->conn->prepare("
			INSERT INTO ".$this->productTable."(sku_id, category_id, product_name, price, brand, material, size, qty, created_date)
			VALUES(?,?,?,?,?,?,?,?,?)");
		
		$this->sku_id = htmlspecialchars(strip_tags($this->sku_id));
		$this->category_id = htmlspecialchars(strip_tags($this->category_id));
		$this->product_name = htmlspecialchars(strip_tags($this->product_name));
		$this->price = htmlspecialchars(strip_tags($this->price));
		$this->brand = htmlspecialchars(strip_tags($this->brand));
		$this->material = htmlspecialchars(strip_tags($this->material));
		$this->size = htmlspecialchars(strip_tags($this->size));
		$this->qty = htmlspecialchars(strip_tags($this->qty));
		$this->created_date = htmlspecialchars(strip_tags($this->created_date));
		
		$stmt->bind_param("sisssssis", $this->sku_id, $this->category_id, $this->product_name, $this->price, $this->brand, $this->material, $this->size, $this->qty, $this->created_date);
		
		if($stmt->execute()){
			return true;
		}
	 
		return false;		 
	}
		
	function update(){
	 
		$stmt = $this->conn->prepare("
			UPDATE ".$this->productTable." 
			SET sku_id= ?, category_id = ?, product_name = ?, price = ?, brand = ?, material = ?, size = ?, qty = ?, created_date = ? 
			WHERE id = ?");
	 
		$this->id = htmlspecialchars(strip_tags($this->id));
		$this->sku_id = htmlspecialchars(strip_tags($this->sku_id));
		$this->category_id = htmlspecialchars(strip_tags($this->category_id));
		$this->product_name = htmlspecialchars(strip_tags($this->product_name));
		$this->price = htmlspecialchars(strip_tags($this->price));
		$this->brand = htmlspecialchars(strip_tags($this->brand));
		$this->material = htmlspecialchars(strip_tags($this->material));
		$this->size = htmlspecialchars(strip_tags($this->size));
		$this->qty = htmlspecialchars(strip_tags($this->qty));
		$this->created_date = htmlspecialchars(strip_tags($this->created_date));
	 
		$stmt->bind_param("sisssssisi", $this->sku_id, $this->category_id, $this->product_name, $this->price, $this->brand, $this->material, $this->size, $this->qty, $this->created_date, $this->id);
		
		if($stmt->execute()){
			return true;
		}
	 
		return false;
	}
	
	function delete(){
		
		$stmt = $this->conn->prepare("
			DELETE FROM ".$this->productTable." 
			WHERE id = ?");
			
		$this->id = htmlspecialchars(strip_tags($this->id));
	 
		$stmt->bind_param("i", $this->id);
	 
		if($stmt->execute()){
			return true;
		}
	 
		return false;		 
	}
}
?>